@@ -33,8 +33,7 @@ import tree
 
 # pylint: disable=g-direct-tensorflow-import
 # Required for specializing `UnrolledLSTM` per device.
-from tensorflow.python import context as context_lib
-from tensorflow.python.eager import function as function_lib
+from tensorflow.python.eager import context as context_lib
 # pylint: enable=g-direct-tensorflow-import
 
 
@@ -1029,9 +1028,9 @@ def _specialize_per_device(api_name, specializations, default):
     unique_api_name = "{}_{}".format(api_name, uuid.uuid4())
     functions = {}
     for device, specialization in specializations.items():
-      functions[device] = function_lib.defun_with_attributes(
+      functions[device] = tf.function(
           specialization,
-          attributes={
+          experimental_attributes={
               "api_implements": unique_api_name,
               "api_preferred_device": device
           })
